##  Adding a View to a Template
The template’s default view controls which color-coding is applied when users preview or generate diagrams from this template. You can apply additional views once a template has been saved, but this doesn’t change the default.
Learn more in [Previewing Diagram Templates](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates?locale=en-US&state=PRODUCTION&version=CLOUD#loio4172dc651578482a82dc63033a4a9170__Previewing-Diagram-Templates).
  1. In the template editor, select a view from the View drop-down list.
  2. Optional: Choose Save if you want to preview the selected view immediately.


Applying a View to a Template
![A gif that shows application, organization, and business capability nodes. The "lifecycle maturity" view is selected from the drop-down list.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa80f9fafcc8648ad94d8003f0fac9827_LowRes.gif)
The selected view is stored with the template and used in previews. Your changes are continually written to your draft.
